-------------
Notifications
-------------

External applications can require synchronisation on events relative
to data availability and can subscribe to particular 
events, e.g., dataset state changes. Rucio will then publish a message
to external application when it detects these events.

